Removed hidden args and hipLaunchParm from HIP/HCC path

이 커밋은 다음에 포함됨:
Rahul Garg
2018-03-16 22:50:25 +05:30
부모 be25556aed
커밋 ed2d4ddfc7
2개의 변경된 파일1개의 추가작업 그리고 2개의 파일을 삭제
+1 -1
파일 보기
@@ -23,7 +23,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
outputData[y * width + x] = tex2D(tex, x, y);